pub unsafe trait CloneableCartablePointerLike: CartablePointerLike { }Expand description
An object that implements CartablePointerLike that also
supports cloning without changing the address of referenced data.
Safety
Implementer safety:
addref_rawmust create a new owner such that an additional call todrop_rawdoes not create a dangling pointeraddref_rawmust not change the address of any referenced data.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".